package com.example.ipawidgetapp;

import java.util.ArrayList;
import java.util.Arrays;

import com.example.ipawidgetapp.R;

import android.app.Activity;
import android.content.SharedPreferences;
import android.os.Bundle;
import android.os.StrictMode;
import android.util.Log;
import android.view.View;
import android.view.View.OnClickListener;
import android.widget.Button;
import android.widget.EditText;
import android.widget.ListView;
import android.widget.TextView;
import android.widget.Toast;

// Activity that builds and handles the ConfigMask
public class ConfigMask extends Activity implements OnClickListener {

//	All saved data will be stored in the SharedPreferences set defined below
	private SharedPreferences sharedSet;
	private SharedPreferences.Editor sharedSetEditor;

	private Button btnConnect;
	private Button btnSave;
	
	private EditText edtURL;
	private EditText edtUsername;
	private EditText edtPassword;
	
	private TextView txtHeaderTitles;
	
	private String url;
	private String username;
	private String password;
	private String[] checked;
	private String sharedChecked;
	
    private ArrayList<Headers> headerList = new ArrayList<Headers>();
    private Headers header;
    private HeaderAdapter headerAdapter;
	
	@Override
	protected void onCreate(Bundle savedInstanceState) {
		super.onCreate(savedInstanceState);
		setContentView(R.layout.activity_config_mask);
		// Required to get access to any URL
		StrictMode.ThreadPolicy policy = new StrictMode.ThreadPolicy.Builder().permitAll().build();
        StrictMode.setThreadPolicy(policy);
		if (Custom_Methods.isWifiOn(this)) {
			Toast.makeText(getApplicationContext(), "WARNING: WLAN Interface active!", Toast.LENGTH_LONG).show();
		}
		sharedSet = getSharedPreferences("Set", Activity.MODE_PRIVATE);
		sharedSetEditor = sharedSet.edit();
		btnConnect = (Button) findViewById(R.id.btnConnect);
		btnConnect.setOnClickListener(this);
		btnSave = (Button) findViewById(R.id.btnSave);
		btnSave.setOnClickListener(this);
		txtHeaderTitles = (TextView) findViewById(R.id.txtHeaderTitles);
		edtURL = (EditText) findViewById(R.id.edtURL);
		edtUsername = (EditText) findViewById(R.id.edtUsername);
		edtPassword = (EditText) findViewById(R.id.edtPassword);
		url = sharedSet.getString("url", "");
		edtURL.setText(url);
		username = sharedSet.getString("username", "");
		edtUsername.setText(username);
		password = sharedSet.getString("password", "");
		edtPassword.setText(password);
		sharedChecked = sharedSet.getString("checked", "");
		checked = sharedChecked.split(","); // the array with the last checked Headertitles we need
	}
	
	public void onClick(View v) {
		if (v.equals(findViewById(R.id.btnConnect))) {
			// Connecting to the website and printing headers
//			sharedSetEditor.putString("checked", ""); // this will clear the headers, we might take a look into that later
			if (Custom_Methods.isWifiOn(getApplicationContext())) {
				Toast.makeText(getApplicationContext(), "WARNING: WLAN Interface active!", Toast.LENGTH_LONG).show();
			} else {
				if (Custom_Methods.HTTPAccess(edtURL.getText().toString(), edtUsername.getText().toString(), edtPassword.getText().toString())) {
					headerList.clear();
					txtHeaderTitles.setText(R.string.txtHeaderTitles);
					String[][] responsetable = Custom_Methods.to2dim(Custom_Methods.getHTTPResponse(edtURL.getText().toString(), edtUsername.getText().toString(), edtPassword.getText().toString()), "\\r?\\n", "\\=");
			        // The final multidimensional array is now ready :3
			        Log.v("ResponseTable: ", Arrays.deepToString(responsetable));
					
			        /* Go through the 2dim and select every first item, then populate the ArrayList out of the
			         * first and check which line it currently is (which array) and also compare this with the
			         * "selected" from SharedPreferences. If it's available, put it on true.
			         */
			        
			        // 2DIM ARRAY ITERATOR
			        for (int table = 0; table < responsetable.length -1; table++) { // -1 because we don't want the ending line (the timestamp) as a selectable header because it is variable
			        	for (int element = 0; element < responsetable[table].length; element++) {
			        		// Only the title has to get selected
			        		if (element == 0) {
			            		// Checking if this header was selected before
				        		if (Arrays.asList(checked).contains('"' + responsetable[table][element] + '"')) {
				        			header = new Headers(responsetable[table][element], true);
				        		} else {
				        			header = new Headers(responsetable[table][element], false);
				        		}
				        		headerList.add(header);
			        		}
			        	}
			        }
			        headerAdapter = new HeaderAdapter(this, R.layout.lsv_headerselection, headerList);
			        ListView lsv_headerselection = (ListView) findViewById(R.id.lsvHeaderSelection);
			        lsv_headerselection.setAdapter(headerAdapter);
				} else {
					Toast.makeText(getApplicationContext(), "Error while connecting to the URL.", Toast.LENGTH_LONG).show();
				} 
			}
		}
		if (v.equals(findViewById(R.id.btnSave))) {
			if (Custom_Methods.isWifiOn(getApplicationContext())) {
				Toast.makeText(getApplicationContext(), "WARNING: WLAN Interface active!", Toast.LENGTH_LONG).show();
			} else {
				if (Custom_Methods.HTTPAccess(edtURL.getText().toString(), edtUsername.getText().toString(), edtPassword.getText().toString())) {
					// Saving everything
					sharedSetEditor.putString("url", edtURL.getText().toString());
					sharedSetEditor.putString("username", edtUsername.getText().toString());
					sharedSetEditor.putString("password", edtPassword.getText().toString()); // CAUTION! NOT YET ENCODED!
					sharedSetEditor.putString("checked", "");
					sharedChecked = "";
					// Checking each header if it was selected or not
					for (Headers header : headerList) {
						if (header.isSelected()) {
							sharedChecked = sharedChecked + '"' + header.getName() + '"' + ","; // For some reason I can't do '",' -> Invalid character constraint ._.
						}
					}
					Log.v("CHECKED", sharedChecked);
					sharedSetEditor.putString("checked", sharedChecked);
					sharedSetEditor.commit();
					finish();
				} else {
					Toast.makeText(getApplicationContext(), "Error while connecting to the URL.", Toast.LENGTH_LONG).show();
				}
			}
		}
	}
}
