package com.example.ipawidgetapp;

import com.example.ipawidgetapp.R;

import android.appwidget.AppWidgetManager;
import android.content.BroadcastReceiver;
import android.content.ComponentName;
import android.content.Context;
import android.content.Intent;
import android.os.StrictMode;
import android.util.Log;
import android.widget.RemoteViews;

// Base class for code that will receive intents sent by getBroadcast() and getActivity() by the class WidgetProvider.
public class WidgetIntentReceiver extends BroadcastReceiver {
	
	// This method is called when the BroadcastReceiver is receiving an Intent broadcast from WidgetProvider.
	@Override
	public void onReceive(Context context, Intent intent) {
		StrictMode.ThreadPolicy policy = new StrictMode.ThreadPolicy.Builder().permitAll().build();
        StrictMode.setThreadPolicy(policy);
		RemoteViews views = new RemoteViews(context.getPackageName(), R.layout.widgetproviderlayout);
        Intent listviewIntent = new Intent(context, WidgetService.class);
		if (intent.getAction().equals("intent_action.REFRESH_WIDGET")) {
			views.setRemoteAdapter(R.id.lsvHeaders, listviewIntent);
			ComponentName thisWidget = new ComponentName(context, WidgetProvider.class);
			AppWidgetManager.getInstance(context).updateAppWidget(thisWidget, views);
			updateListView(context);
			Log.v("Refresh", "Refresh active");
		} else {
			Log.e("UNKOWN_ACTION", "An unknown action has been executed: " + intent.getAction());
			//UNKNOWN ACTION ERROR
		}
		views.setOnClickPendingIntent(R.id.touchable_layout, WidgetProvider.ShowWebsite(context)); // The layout is still toucheable, but if the layout is filled, there's no free place to touch
		views.setOnClickPendingIntent(R.id.btnWebsite, WidgetProvider.ShowWebsite(context));
		views.setOnClickPendingIntent(R.id.btnRefresh, WidgetProvider.RefreshWidget(context));
		views.setOnClickPendingIntent(R.id.btnConfig, WidgetProvider.ConfigMask(context));
		WidgetProvider.pushWidgetUpdate(context, views);
	}
	
//	Specifically updating the ListView on the AppWidget - calling WidgetService
	private void updateListView(Context context) {
		AppWidgetManager appWidgetManager = AppWidgetManager.getInstance(context);
	    int appWidgetIds[] = appWidgetManager.getAppWidgetIds(new ComponentName(context, WidgetProvider.class));
	    appWidgetManager.notifyAppWidgetViewDataChanged(appWidgetIds, R.id.lsvHeaders);
	}
}
